@@ -1,8 +1,9 @@
 test_that("get_landsat_imagery() is stable", {
   skip_on_cran()
+  skip_if_offline()
   aoi <- sf::st_point(c(-74.912131, 44.080410))
   aoi <- sf::st_set_crs(sf::st_sfc(aoi), 4326)
-  aoi <- sf::st_buffer(sf::st_transform(aoi, 3857), 1000)
+  aoi <- sf::st_buffer(sf::st_transform(aoi, 3857), 100)
 
   expect_no_error(
     out <- get_landsat_imagery(
@@ -23,9 +24,10 @@ test_that("get_landsat_imagery() is stable", {
 
 test_that("get_sentinel1_imagery() is stable", {
   skip_on_cran()
+  skip_if_offline()
   aoi <- sf::st_point(c(-74.912131, 44.080410))
   aoi <- sf::st_set_crs(sf::st_sfc(aoi), 4326)
-  aoi <- sf::st_buffer(sf::st_transform(aoi, 3857), 1000)
+  aoi <- sf::st_buffer(sf::st_transform(aoi, 3857), 100)
 
   expect_no_error(
     out <- get_sentinel1_imagery(
@@ -46,9 +48,10 @@ test_that("get_sentinel1_imagery() is stable", {
 
 test_that("get_sentinel2_imagery() is stable", {
   skip_on_cran()
+  skip_if_offline()
   aoi <- sf::st_point(c(-74.912131, 44.080410))
   aoi <- sf::st_set_crs(sf::st_sfc(aoi), 4326)
-  aoi <- sf::st_buffer(sf::st_transform(aoi, 3857), 1000)
+  aoi <- sf::st_buffer(sf::st_transform(aoi, 3857), 100)
 
   expect_no_error(
     out <- get_sentinel2_imagery(
@@ -70,9 +73,10 @@ test_that("get_sentinel2_imagery() is stable", {
 
 test_that("get_dem() is stable", {
   skip_on_cran()
+  skip_if_offline()
   aoi <- sf::st_point(c(-74.912131, 44.080410))
   aoi <- sf::st_set_crs(sf::st_sfc(aoi), 4326)
-  aoi <- sf::st_buffer(sf::st_transform(aoi, 3857), 1000)
+  aoi <- sf::st_buffer(sf::st_transform(aoi, 3857), 100)
 
   expect_no_error(
     out <- get_dem(
@@ -91,9 +95,10 @@ test_that("get_dem() is stable", {
 
 test_that("non-default mappings work", {
   skip_on_cran()
+  skip_if_offline()
   aoi <- sf::st_point(c(-74.912131, 44.080410))
   aoi <- sf::st_set_crs(sf::st_sfc(aoi), 4326)
-  aoi <- sf::st_buffer(sf::st_transform(aoi, 3857), 1000)
+  aoi <- sf::st_buffer(sf::st_transform(aoi, 3857), 100)
 
   expect_no_error(
     out <- get_sentinel2_imagery(
@@ -116,9 +121,10 @@ test_that("non-default mappings work", {
 test_that("can download RTC products", {
   skip_if(Sys.getenv("rsi_pc_key") == "", "Environment variable `rsi_pc_key` not set")
   skip_on_cran()
+  skip_if_offline()
   aoi <- sf::st_point(c(-74.912131, 44.080410))
   aoi <- sf::st_set_crs(sf::st_sfc(aoi), 4326)
-  aoi <- sf::st_buffer(sf::st_transform(aoi, 3857), 1000)
+  aoi <- sf::st_buffer(sf::st_transform(aoi, 3857), 100)
 
   expect_no_error(
     out <- get_sentinel1_imagery(
@@ -140,9 +146,10 @@ test_that("can download RTC products", {
 
 test_that("hidden arguments work", {
   skip_on_cran()
+  skip_if_offline()
   aoi <- sf::st_point(c(-74.912131, 44.080410))
   aoi <- sf::st_set_crs(sf::st_sfc(aoi), 4326)
-  aoi <- sf::st_buffer(sf::st_transform(aoi, 3857), 1000)
+  aoi <- sf::st_buffer(sf::st_transform(aoi, 3857), 100)
 
   expect_no_error(
     out <- get_landsat_imagery(
@@ -165,9 +172,10 @@ test_that("hidden arguments work", {
 
 test_that("simple merge method works", {
   skip_on_cran()
+  skip_if_offline()
   aoi <- sf::st_point(c(-74.912131, 44.080410))
   aoi <- sf::st_set_crs(sf::st_sfc(aoi), 4326)
-  aoi <- sf::st_buffer(sf::st_transform(aoi, 3857), 1000)
+  aoi <- sf::st_buffer(sf::st_transform(aoi, 3857), 100)
 
   expect_no_error(
     out <- get_stac_data(
@@ -187,9 +195,10 @@ test_that("simple merge method works", {
 
 test_that("warning (but not error) fires if `mask_band` is not NULL with NULL `mask_function`", {
   skip_on_cran()
+  skip_if_offline()
   aoi <- sf::st_point(c(-74.912131, 44.080410))
   aoi <- sf::st_set_crs(sf::st_sfc(aoi), 4326)
-  aoi <- sf::st_buffer(sf::st_transform(aoi, 3857), 1000)
+  aoi <- sf::st_buffer(sf::st_transform(aoi, 3857), 100)
 
   expect_snapshot(
     x <- get_landsat_imagery(
@@ -205,9 +214,10 @@ test_that("warning (but not error) fires if `mask_band` is not NULL with NULL `m
 
 test_that("get_*_data works with mapply() (#17)", {
   skip_on_cran()
+  skip_if_offline()
   san_antonio = sf::st_point(c(-98.491142, 29.424349))
   san_antonio = sf::st_sfc(san_antonio, crs = "EPSG:4326")
-  san_antonio = sf::st_buffer(sf::st_transform(san_antonio, "EPSG:3081"), 1000)
+  san_antonio = sf::st_buffer(sf::st_transform(san_antonio, "EPSG:3081"), 100)
 
   expect_no_error(
     mapply(
@@ -226,12 +236,12 @@ test_that("proper error if no items are found", {
 
   aoi <- sf::st_point(c(-74.912131, 44.080410))
   aoi <- sf::st_set_crs(sf::st_sfc(aoi), 4326)
-  aoi <- sf::st_buffer(sf::st_transform(aoi, 5070), 1000)
+  aoi <- sf::st_buffer(sf::st_transform(aoi, 5070), 100)
 
   expect_error(
     get_stac_data(
       aoi,
-      start_date = "1970-01-01",
+      start_date = "1970-01-01", # pre-LCMAP dates
       end_date = "1970-12-31",
       asset_names = "lcpri",
       stac_source = "https://planetarycomputer.microsoft.com/api/stac/v1/",
@@ -253,7 +263,7 @@ test_that("no-composite paths work on Windows #29, #32", {
       sf::st_sfc(sf::st_point(c(-74.912131, 44.080410)), crs = 4326),
       3857
     ),
-    1000
+    100
   )
 
   expect_no_error(
@@ -264,5 +274,31 @@ test_that("no-composite paths work on Windows #29, #32", {
       composite_function = NULL
     )
   )
+})
 
+test_that("no-composites return the same data", {
+  skip_if_offline()
+  skip_on_cran()
+
+  aoi <- sf::st_buffer(
+    sf::st_transform(
+      sf::st_sfc(sf::st_point(c(-74.912131, 44.080410)), crs = 4326),
+      3857
+    ),
+    100
+  )
+
+  expect_contains(
+    names(
+      terra::rast(
+        get_landsat_imagery(
+          aoi = aoi,
+          start_date = "2022-07-01",
+          end_date = "2022-07-05",
+          composite_function = NULL
+        )
+      )
+    ),
+    setdiff(rsi::landsat_band_mapping$planetary_computer_v1, "T")
+  )
 })
